@@ -3,16 +3,16 @@
 
 from __future__ import annotations
 
-import logging
+from logging import getLogger
 from typing import Any, ClassVar, Optional
 
-from metabase_tools.common import log_call
 from metabase_tools.endpoints.generic_endpoint import Endpoint
 from metabase_tools.exceptions import InvalidParameters
 from metabase_tools.models.generic_model import MissingParam
 from metabase_tools.models.user_model import UserItem
+from metabase_tools.utils.logging_utils import log_call
 
-logger = logging.getLogger(__name__)
+logger = getLogger(__name__)
 
 
 class Users(Endpoint[UserItem]):
